package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbExamSubject;
import com.ruoyi.hezhi.domain.TbExamSubjectFormal;

import java.util.List;
import java.util.Map;

/**
 * 正式考试题目Mapper接口
 *
 * @author ruoyi
 * @date 2024-11-13
 */
public interface TbExamSubjectFormalMapper
{
    /**
     * 查询正式考试题目
     *
     * @param examSubjectFormalId 正式考试题目主键
     * @return 正式考试题目
     */
    public TbExamSubjectFormal selectTbExamSubjectFormalByExamSubjectFormalId(Long examSubjectFormalId);

    /**
     * 查询正式考试题目列表
     *
     * @param tbExamSubjectFormal 正式考试题目
     * @return 正式考试题目集合
     */
    public List<TbExamSubjectFormal> selectTbExamSubjectFormalList(TbExamSubjectFormal tbExamSubjectFormal);

    /**
     * 新增正式考试题目
     *
     * @param tbExamSubjectFormal 正式考试题目
     * @return 结果
     */
    public int insertTbExamSubjectFormal(TbExamSubjectFormal tbExamSubjectFormal);

    /**
     * 修改正式考试题目
     *
     * @param tbExamSubjectFormal 正式考试题目
     * @return 结果
     */
    public int updateTbExamSubjectFormal(TbExamSubjectFormal tbExamSubjectFormal);

    /**
     * 删除正式考试题目
     *
     * @param examSubjectFormalId 正式考试题目主键
     * @return 结果
     */
    public int deleteTbExamSubjectFormalByExamSubjectFormalId(Long examSubjectFormalId);

    /**
     * 批量删除正式考试题目
     *
     * @param examSubjectFormalIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbExamSubjectFormalByExamSubjectFormalIds(Long[] examSubjectFormalIds);

    /**
     * 删除正式考试题目
     *
     * @param examId 考试ID
     * @return 结果
     */
    public int deleteTbExamSubjectFormalByExamId(Long examId);

    /**
     * 批量新增模拟考试题目
     *
     * @param list 考试题目列表
     * @return 结果
     */
    public int batchInsertTbExamSubjectFormalBy(List<TbExamSubject> list);

    /**
     * 查询所有题目
     *
     * @param params 参数
     * @return 结果
     */
    public List<Map<String,Object>> getAllTbExamSubjectFormal(Map<String,Object> params);
}
